export declare class Vector {
    readonly values: number[];
    constructor(...values: number[]);
    get dim(): number;
    get x(): number;
    set x(value: number);
    get y(): number;
    set y(value: number);
    get z(): number;
    set z(value: number);
    get w(): number;
    set w(value: number);
    get xy(): Vector;
    get xz(): Vector;
    get yz(): Vector;
    get xyz(): Vector;
    /**
     * Sets the values of this vector
     * @param values
     * @returns
     */
    set(...values: number[]): Vector;
    /**
     * Create vector from Array
     * @param arr array of numbers
     */
    static fromArray(arr: number[]): Vector;
    /**
     * Create vector with x = y = n
     * @param n the number
     * @param dim the dimension
     */
    static fromNumber(n: number, dim: number): Vector;
    /**
     * clone vector
     */
    clone(): Vector;
    /**
     * add vector
     * @param otherVec addend
     * @returns addition result
     */
    add(otherVec: Vector): Vector;
    /**
     * subtract vector
     * @param otherVec addend
     * @returns subtraction result
     */
    sub(otherVec: Vector): Vector;
    /**
     * multiply vector with scalar
     * @param value scalar
     * @returns multiplication result
     */
    mul(value: number): Vector;
    /**
     * divide vector with scalar
     * @param value scalar
     * @returns multiplication result
     */
    div(value: number): Vector;
    /**
     * dot product
     * @param otherVec
     */
    dot(otherVec: Vector): number;
    /**
     * check for equality
     * @param otherVec
     */
    equals(otherVec: Vector): boolean;
    /**
     * Calculate length
     */
    get length(): number;
    /**
     * Convert to array
     */
    toArray(): number[];
    /**
     * Convert to string, in the form of `(x, y)`
     */
    toString(): string;
    /**
     * cross product
     * @param otherVec
     * @returns new Vec3 instance containing cross product
     */
    cross(otherVec: Vector): Vector;
    /**
     * normalized vector,
     * @returns vector normalized to length = 1
     */
    get normalized(): Vector;
}
