import { BufferGeometry } from '../geometries';
import { Material } from './material';
export declare class Mesh {
    geometry: BufferGeometry;
    material: Material;
    bufferUsage: number;
    buffers: Record<string, WebGLBuffer>;
    program: WebGLProgram | null;
    gl: WebGLRenderingContext | null;
    /**
     * Mesh constructor
     * @param geometry a buffer geometry
     * @param material the material
     */
    constructor(geometry: BufferGeometry, material: Material, bufferUsage?: number);
    /**
     * Initialize this mesh inside a WebGLRenderingContext, does nothing if already initialized.
     * @param gl the WebGLRenderingContext
     * @returns
     */
    init(gl: WebGLRenderingContext): void;
    private compileShader;
    private createProgram;
    private createBuffers;
    private deleteBuffers;
    /**
     * Update all buffers
     * @returns this instance
     */
    updateBuffers(): Mesh;
    /**
     * Update buffer of a single attribute
     * @param attribName name of the attribute to be updated
     * @param newData the new data
     * @param offset offset (default = 0)
     * @param syncGeometry also keep the underlying geometry data in sync (default = true)
     * @returns current instance
     */
    updateBuffer(attribName: string, newData: Float32Array, offset?: number, syncGeometry?: boolean): Mesh;
    /**
     * Recompile shaders
     * @returns this instance
     */
    recompile(): Mesh;
    /**
     * Set uniform variables
     * @returns this instance
     */
    setUniforms(): Mesh;
    /**
     * enable attributes
     * @returns this instance
     */
    disableAttribs(): Mesh;
    /**
     * disable attributes
     * @returns this instance
     */
    enableAttribs(): Mesh;
    /**
     * Call drawElements or drawArrays
     * @returns this instance
     */
    draw(): Mesh;
    /**
     * Free attributes, buffers and delete the program and disconnect the mesh from the WebGL context
     */
    dispose(): void;
}
